@@ -141,6 +141,8 @@ KNOWN_EXTENSIONS = (
     'provider',
     'qos',
     'qos-bw-limit-direction',
+    'qos-fip',
+    'qos-fip-network-policy',
     'qos-gateway-ip',
     'qos-port-network-policy',
     'qos-pps-minimum',
